CANFrame

Struct CANFrame 

pub struct CANFrame {
    pub can_cobid: u32,
    pub can_len: usize,
    pub can_data: [u8; 8],
}
A structure representing RAW CAN frames.

Fields

  • can_cobid - The CAN identifier (COB-ID) of the frame. This is a 32-bit value that uniquely identifies the frame in the CAN network.
  • can_len - The length of the CAN frame. Number of valid bytes in can_data
  • can_data - The data of the CAN frame. This is an array of 8 bytes containing the payload of the frame.

Fields

can_cobid: u32

The CAN identifier (COB-ID) of the frame.

This is a 32-bit value that uniquely identifies the frame in the CAN network.

can_len: usize

The length of the CAN frame

can_data: [u8; 8]

The data of the CAN frame.

This is an array of 8 bytes containing the payload of the frame.

Implementations

Source

impl CANFrame

pub fn write_to_slice(&self, buffer: &mut [u8])

Serializes raw CAN frame