pub struct CANFrame {
pub can_cobid: u32,
pub can_len: usize,
pub can_data: [u8; 8],
}Expand description
A structure representing RAW CAN frames.
Fields
can_cobid- The CAN identifier (COB-ID) of the frame. This is a 32-bit value that uniquely identifies the frame in the CAN network.can_len- The length of the CAN frame. Number of valid bytes incan_datacan_data- The data of the CAN frame. This is an array of 8 bytes containing the payload of the frame.
Fields
can_cobid: u32The CAN identifier (COB-ID) of the frame.
This is a 32-bit value that uniquely identifies the frame in the CAN network.
can_len: usizeThe length of the CAN frame
can_data: [u8; 8]The data of the CAN frame.
This is an array of 8 bytes containing the payload of the frame.
Implementations